Class: DuffelAPI::Services::WebhooksService::PingResult
- Inherits:
-
Object
- Object
- DuffelAPI::Services::WebhooksService::PingResult
- Defined in:
- lib/duffel_api/services/webhooks_service.rb
Instance Attribute Summary collapse
-
#api_response ⇒ Object
readonly
Returns the value of attribute api_response.
Instance Method Summary collapse
-
#initialize(api_response) ⇒ PingResult
constructor
A new instance of PingResult.
-
#succeeded ⇒ Object
If we return a
PingResultrather than an error, then that means that the action was successful.
Constructor Details
#initialize(api_response) ⇒ PingResult
Returns a new instance of PingResult.
9 10 11 |
# File 'lib/duffel_api/services/webhooks_service.rb', line 9 def initialize(api_response) @api_response = api_response end |
Instance Attribute Details
#api_response ⇒ Object (readonly)
Returns the value of attribute api_response.
7 8 9 |
# File 'lib/duffel_api/services/webhooks_service.rb', line 7 def api_response @api_response end |
Instance Method Details
#succeeded ⇒ Object
If we return a PingResult rather than an error, then that means that the action was successful.
15 16 17 |
# File 'lib/duffel_api/services/webhooks_service.rb', line 15 def succeeded true end |